"""测试 entry points 注册和发现。"""

from __future__ import annotations


def test_backend_entry_points_registered():
    """测试 backend entry points 是否正确注册。"""
    from sagellm_backend.providers.mock import create_mock_backend

    from sagellm_backend.providers.cpu import create_cpu_backend

    # 验证工厂函数可以直接调用
    mock_backend = create_mock_backend()
    assert mock_backend is not None

    cpu_backend = create_cpu_backend()
    assert cpu_backend is not None



"""Providers 包初始化"""

from __future__ import annotations

from sagellm_backend.providers.cpu import CPUBackendProvider, create_cpu_backend
from sagellm_backend.providers.cuda import CudaBackendProvider

# PyTorch providers (optional dependencies)
try:
    from sagellm_backend.providers.pytorch_cuda import (
        PyTorchCUDABackendProvider,
        create_pytorch_cuda_backend,
    )

    _PYTORCH_CUDA_AVAILABLE = True
except ImportError:
    _PYTORCH_CUDA_AVAILABLE = False
    PyTorchCUDABackendProvider = None  # type: ignore
    create_pytorch_cuda_backend = None  # type: ignore

try:
    from sagellm_backend.providers.pytorch_ascend import (
        PyTorchAscendBackendProvider,
        create_pytorch_ascend_backend,
    )

    _PYTORCH_ASCEND_AVAILABLE = True
except ImportError:
    _PYTORCH_ASCEND_AVAILABLE = False
    PyTorchAscendBackendProvider = None  # type: ignore
    create_pytorch_ascend_backend = None  # type: ignore

__all__ = [
    "CPUBackendProvider",
    "create_cpu_backend",
    "CudaBackendProvider",
    # PyTorch providers (may be None if not installed)
    "PyTorchCUDABackendProvider",
    "create_pytorch_cuda_backend",
    "PyTorchAscendBackendProvider",
    "create_pytorch_ascend_backend",
]
